@@ -29,7 +29,7 @@ def sntsmkf(pairs:list =[["She has ready.","She is ready."], ["It are ok.","It i
 		print(">>gecv1_dsk Ex:", ex, "\t|", sntdic)
 		exc_type, exc_value, exc_traceback_obj = sys.exc_info()
 		traceback.print_tb(exc_traceback_obj)
-		return str(ex)
+		return {"failed":str(ex)}
 
 if __name__ == '__main__':
 	print( sntsmkf( asdsk=False))
\ No newline at end of file
