@@ -4,7 +4,7 @@ import sqlite3,json,collections, fire, traceback,sys
 from collections import	UserDict,Counter,defaultdict
 from tqdm import tqdm
 
-from en import * #import en # need 3.1.1
+import en # need 3.1.1 #from en import * #
 from en import terms,verbnet
 attach = lambda doc: ( terms.attach(doc), verbnet.attach(doc), doc.user_data )[-1]  # return ssv, defaultdict(dict)
 
@@ -80,7 +80,7 @@ class util(object):
 		conn = init_db(outfile)
 		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
 			try:
-				doc = frombs(bs)
+				doc = spacy.frombs(bs)
 				kps = " ".join([ f"{t.pos_}_{t.lemma_}" for t in doc] + [ f"{t.tag_}_{t.lemma_}" for t in doc] + [ f"{t.dep_}_{t.head.pos_}_{t.pos_}_{t.head.lemma_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp')])
 				conn.execute(f"insert or ignore into fts(rowid, snt,terms) values(?,?,?)", (rowid, snt, kps ))
 			except Exception as e:
@@ -96,7 +96,7 @@ class util(object):
 		ssi = defaultdict(Counter) 
 		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
 			try:
-				doc = frombs(bs)
+				doc = spacy.frombs(bs)
 				terms.zset_ssi(doc, ssi)
 				if fts: doc_fts(conn, rowid, snt, doc) 
 			except Exception as e:
@@ -120,9 +120,9 @@ class util(object):
 			try:
 				did		= row[0]
 				essay	= row[1]
-				for i,snt in enumerate(snts(essay) ): 
-					doc = nlp(snt) #frombs(bs)
-					if snt and not snt in db: db[snt] = tobs(nlp(snt))
+				for i,snt in enumerate(spacy.snts(essay) ): 
+					doc = spacy.nlp(snt) #frombs(bs)
+					if snt and not snt in db: db[snt] = spacy.tobs(nlp(snt))
 					conn.execute(f"insert or ignore into fts(sid, snt,terms) values(?,?,?)", (f"{did}-{i}", snt, " ".join([ f"{t.pos_}_{t.lemma_}" for t in doc] + [ f"{t.tag_}_{t.lemma_}" for t in doc] + [ f"{t.dep_}_{t.head.pos_}_{t.pos_}_{t.head.lemma_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp')]) ))
 					if ssi: terms.zset_ssi(doc, ssi)
 			except Exception as e:
@@ -138,7 +138,7 @@ class util(object):
 		si = Counter()
 		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
 			try:
-				doc = frombs(bs)
+				doc = spacy.frombs(bs)
 				for t in doc:
 					si.update({f"{t.pos_}:{t.lemma_}":1}) # VERB:book 
 					si.update({f"LEM:{t.lemma_}":1})
@@ -161,7 +161,7 @@ class util(object):
 			try:
 				snt = line.strip()
 				if snt and not snt in db: 
-					db[snt] = tobs(nlp(snt))
+					db[snt] = spacy.tobs(spacy.nlp(snt))
 			except Exception as e:
 				print ("parse ex:", e, line)
 		db.close()
@@ -176,9 +176,9 @@ class util(object):
 		rdm.delete(f"snts:{name}")
 		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
 			try:
-				doc = frombs(bs)
+				doc = spacy.frombs(bs)
 				rdm.rpush(f"snts:{name}", snt ) 
-				rbs.setnx(snt, tobs(doc))
+				rbs.setnx(snt, spacy.tobs(doc))
 			except Exception as e:
 				print ("ex:", e, rowid, snt)
 		print (f"[tobs] finished, {dbfile}, {name}")
@@ -192,7 +192,7 @@ class util(object):
 		with open(outfile, 'w') as fw:
 			for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
 				try:
-					doc = frombs(bs) 
+					doc = spacy.frombs(bs) 
 					ssv = attach(doc) 
 					for id, source in ssv.items():
 						source.update({"src": rowid})
@@ -215,7 +215,7 @@ class util(object):
 		actions=[]
 		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
 			try:
-				doc = frombs(bs) 
+				doc = spacy.frombs(bs) 
 				actions.append({'_op_type':'index', '_index':idxname, '_id': rowid, '_source':{'type':'snt', 'snt':snt,
 				'postag':'^ ' + ' '.join([f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" if t.text == t.text.lower() else f"{t.text}_{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc]) + ' $',
 				'src': rowid,  'tc': len(doc)}}) #'sid': rowid,
@@ -314,10 +314,5 @@ sqlite> select * from ssi where s like '~dobj_VERB_NOUN:difficulty %' order by i
 ~dobj_VERB_NOUN:difficulty find|1
 
 select snt from fts where terms match('dobj_VERB_NOUN_overcome_difficulty')  limit 10;
-
-
 select * from ssi where s in ('dobj_VERB_NOUN:overcome difficulty','~amod_NOUN_ADJ:front door')
-
-
-
 '''
\ No newline at end of file
