@@ -3,8 +3,6 @@ import requests,json, os, math,re
 from elasticsearch import Elasticsearch,helpers
 from collections import	Counter
 
-#os.environ['eshost'] = 'es.corpusly.com'
-#from so imoprt *
 eshost	= os.getenv("eshost", "127.0.0.1") 
 esport	= int(os.getenv("esport", 9200))
 #requests.put(f"http://{eshost}:{esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
@@ -82,6 +80,7 @@ config = {
 			"feedback": { "type": "text", "analyzer": "feedback_ana" ,"fielddata":"true" },
 			"kps": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
 			"postag": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
+			"skenp": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"i": { "type": "integer"},
@@ -94,6 +93,8 @@ config = {
 			"id": { "type": "keyword"},
 			"rid": { "type": "integer"},
 			"did": { "type": "integer"},
+			"ibeg": { "type": "integer"},
+			"iend": { "type": "integer"},
 			"docid": { "type": "keyword"},
 			"uid": { "type": "integer"},
 			"eid": { "type": "integer"},
@@ -127,7 +128,6 @@ config = {
 			"content": { "type": "text", "analyzer": "standard","fielddata":"true"},
 			"zhseg": { "type": "text", "analyzer": "standard"},
 			"zh": { "type": "text", "index": "false"},
-
 			"src": { "type": "keyword"},
 			"srcsnt": { "type": "keyword"},
 			"segtype": { "type": "keyword"},
