@@ -20,6 +20,19 @@ class ES(object):
 					print (file, folder, flush=True)
 		print("addfolder finished:", folder, idxname, self.es, flush=True)
 
+
+	def annotate(self, infile, idxname): 
+		''' 2022.3.24 '''
+		from en import esjson
+		print("annotate started:", infile, idxname, self.es, flush=True)
+		if not self.es.indices.exists(idxname): self.es.indices.create(idxname, config)
+
+		text = open(infile,'r').read().strip()
+		ssv  = esjson.annotate(text ) 
+		for id, sv in ssv.items(): 
+			self.es.index(index = idxname, id = id, body = sv)
+		print("annotate finished:", infile,idxname)
+
 	def loadjukuu(self, infile, idxname, batch=100000): 
 		''' 2022.1.11 '''
 		print("loadsource started:", infile, idxname, self.es, flush=True)
